translate.storage.utx.UtxHeader

Package translate :: Package storage :: Module utx :: Class UtxHeader |
[hide private]
[frames] | no frames]

# Class UtxHeader

source code

A UTX header entry

A UTX header is a single line that looks like this:

       #UTX-S <version>; < source language >/< target language>;
       <date created>; <optional fields (creator, license, etc.)>

Where:

       - UTX-S version is currently 1.00.
       - Source language/target language: ISO 639, 3166 formats.
         In the case of monolingual dictionary, target language should be
         omitted.
       - Date created: ISO 8601 format
       - Optional fields (creator, license, etc.)